summaryrefslogtreecommitdiffstats
path: root/libk9copy/mp4dlg.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libk9copy/mp4dlg.cpp')
-rw-r--r--libk9copy/mp4dlg.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/libk9copy/mp4dlg.cpp b/libk9copy/mp4dlg.cpp
index 252c9f0..59f0571 100644
--- a/libk9copy/mp4dlg.cpp
+++ b/libk9copy/mp4dlg.cpp
@@ -22,11 +22,11 @@
#include "kpushbutton.h"
/*
* Constructs a MP4Dlg as a child of 'tqparent', with the
* name 'name' and widget flags set to 'f'.
*/
-MP4Dlg::MP4Dlg( TQWidget* tqparent, const char* name, WFlags fl )
- : TQWidget( tqparent, name, fl )
+MP4Dlg::MP4Dlg( TQWidget* parent, const char* name, WFlags fl )
+ : TQWidget( parent, name, fl )
{
if ( !name )
setName( "MP4Dlg" );
@@ -22,11 +22,11 @@
#include "kpushbutton.h"
/*
- * Constructs a MP4Dlg as a child of 'tqparent', with the
+ * Constructs a MP4Dlg as a child of 'parent', with the
* name 'name' and widget flags set to 'f'.
*/